==> eiffelstudio-16.05.tar: F_code/C25/eg1242.c <==
/*
 * Code for class EG_GRID_LAYOUT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "eg1242.h"
#include <math.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EG_GRID_LAYOUT}.default_create */
void F1654_19581 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("default_create", 1653, Current, 0, 0, 17721);
	RTGC;
	RTHOOK(1);
	F1_29(Current);
	RTHOOK(2);
	*(EIF_REAL_64 *)(Current+ _R64OFF_1_0_0_5_0_0_0_0_) = (EIF_REAL_64) (EIF_REAL_64) 1.0;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {EG_GRID_LAYOUT}.set_point_a_position */
void F1654_19590 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("set_point_a_position", 1653, Current, 0, 2, 17730);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) arg2;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {EG_GRID_LAYOUT}.set_point_b_position */
void F1654_19591 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("set_point_b_position", 1653, Current, 0, 2, 17731);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_3_) = (EIF_INTEGER_32) arg2;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {EG_GRID_LAYOUT}.set_number_of_columns */
void F1654_19593 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_number_of_columns", 1653, Current, 0, 1, 17719);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_) = (EIF_INTEGER_32) arg1;
	RTHOOK(2);
	RTEE;
}

/* {EG_GRID_LAYOUT}.layout_linkables */
void F1654_19594 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REAL_64 tr8_1;
	EIF_REAL_64 tr8_2;
	EIF_REAL_64 tr8_3;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc10);
	RTLIU(4);
	
	RTEAA("layout_linkables", 1653, Current, 10, 3, 17720);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_) == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(2);
		loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_);
		loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 / ((EIF_INTEGER_32) 2L)) + (EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)));
		RTHOOK(3);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	} else {
		RTHOOK(4);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_);
		tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 - ti4_2)));
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_);
		tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))));
		tr8_3 = *(EIF_REAL_64 *)(Current+ _R64OFF_1_0_0_5_0_0_0_0_);
		loc1 = (EIF_INTEGER_32) ((EIF_REAL_64) ((EIF_REAL_64) (tr8_1) /  (EIF_REAL_64) ((EIF_REAL_64) (tr8_2 * (EIF_REAL_64) pow ((EIF_REAL_64) (arg2), (EIF_REAL_64) (tr8_3))))));
		RTHOOK(5);
		loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	}
	RTHOOK(6);
	ti4_1 = F2640_29141(RTCW(arg1));
	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_);
	tr1 = RTLNS(eif_new_type(3797, 0x00).id, 3797, _OBJSIZ_0_0_0_0_0_0_0_1_);
	*(EIF_REAL_64 *)tr1 = (EIF_REAL_64) ((EIF_REAL_64) (ti4_1) /  (EIF_REAL_64) (ti4_2));
	loc5 = F3796_46495(RTCW(tr1));
	RTHOOK(7);
	if ((EIF_BOOLEAN)(loc5 == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(8);
		loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_3_);
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 2L)) + (EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)));
		RTHOOK(9);
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	} else {
		RTHOOK(10);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_3_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
		tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 - ti4_2)));
		tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) (loc5 - ((EIF_INTEGER_32) 1L))));
		tr8_3 = *(EIF_REAL_64 *)(Current+ _R64OFF_1_0_0_5_0_0_0_0_);
		loc2 = (EIF_INTEGER_32) ((EIF_REAL_64) ((EIF_REAL_64) (tr8_1) /  (EIF_REAL_64) ((EIF_REAL_64) (tr8_2 * (EIF_REAL_64) pow ((EIF_REAL_64) (arg2), (EIF_REAL_64) (tr8_3))))));
		RTHOOK(11);
		loc2 /= arg2;
		RTHOOK(12);
		loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	}
	RTHOOK(13);
	loc6 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTHOOK(14);
	loc9 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(15);
	loc8 = F2640_29141(RTCW(arg1));
	for (;;) {
		RTHOOK(16);
		if ((EIF_BOOLEAN) (loc6 >= loc5)) break;
		RTHOOK(17);
		loc7 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		for (;;) {
			RTHOOK(18);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc7 >= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_)) || (EIF_BOOLEAN) (loc9 > loc8))) break;
			RTHOOK(19);
			loc10 = F2640_29126(RTCW(arg1), loc9);
			RTHOOK(20);
			if ((EIF_BOOLEAN)(arg2 == ((EIF_INTEGER_32) 1L))) {
				RTHOOK(21);
				F5557_75794(RTCW(loc10), (EIF_INTEGER_32) (loc3 + (EIF_INTEGER_32) (loc7 * loc1)), (EIF_INTEGER_32) (loc4 + (EIF_INTEGER_32) (loc6 * loc2)));
			} else {
				RTHOOK(22);
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9333[Dtype(loc10)-490])(RTCW(loc10));
				ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R9334[Dtype(loc10)-490])(RTCW(loc10));
				F5557_75794(RTCW(loc10), (EIF_INTEGER_32) (ti4_1 + (EIF_INTEGER_32) (loc7 * loc1)), (EIF_INTEGER_32) (ti4_2 + (EIF_INTEGER_32) (loc6 * loc2)));
			}
			RTHOOK(23);
			loc9++;
			RTHOOK(24);
			loc7++;
		}
		RTHOOK(25);
		loc6++;
	}
	RTHOOK(26);
	RTLE;
	RTEE;
}

void EIF_Minit1242 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C25/eg1242.c <==
/*
 * Code for class EG_GRID_LAYOUT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "eg1242.h"
#include <math.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EG_GRID_LAYOUT}.default_create */
void F1374_19567 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("default_create", 1373, Current, 0, 0, 17071);
	RTGC;
	RTHOOK(1);
	{
		/* INLINED CODE (ANY.default_create) */
		/* END INLINED CODE */
	}
	;
	RTHOOK(2);
	*(EIF_REAL_64 *)(Current+ _R64OFF_1_0_0_5_0_0_0_0_) = (EIF_REAL_64) (EIF_REAL_64) 1.0;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {EG_GRID_LAYOUT}.set_point_a_position */
void F1374_19576 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("set_point_a_position", 1373, Current, 0, 2, 17080);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) arg2;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {EG_GRID_LAYOUT}.set_point_b_position */
void F1374_19577 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("set_point_b_position", 1373, Current, 0, 2, 17081);
	RTGC;
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_3_) = (EIF_INTEGER_32) arg2;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {EG_GRID_LAYOUT}.set_number_of_columns */
void F1374_19579 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_number_of_columns", 1373, Current, 0, 1, 17083);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_) = (EIF_INTEGER_32) arg1;
	RTHOOK(3);
	RTEE;
}

/* {EG_GRID_LAYOUT}.layout_linkables */
void F1374_19580 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REAL_64 tr8_1;
	EIF_REAL_64 tr8_2;
	EIF_REAL_64 tr8_3;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc10);
	RTLIU(4);
	
	RTEAA("layout_linkables", 1373, Current, 10, 3, 17084);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_) == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(2);
		loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_);
		loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 / ((EIF_INTEGER_32) 2L)) + (EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)));
		RTHOOK(3);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	} else {
		RTHOOK(4);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_);
		tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 - ti4_2)));
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_);
		tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))));
		tr8_3 = *(EIF_REAL_64 *)(Current+ _R64OFF_1_0_0_5_0_0_0_0_);
		loc1 = (EIF_INTEGER_32) ((EIF_REAL_64) ((EIF_REAL_64) (tr8_1) /  (EIF_REAL_64) ((EIF_REAL_64) (tr8_2 * (EIF_REAL_64) pow ((EIF_REAL_64) (arg2), (EIF_REAL_64) (tr8_3))))));
		RTHOOK(5);
		loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	}
	RTHOOK(6);
	ti4_1 = F2640_30089(RTCW(arg1));
	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_);
	tr1 = RTLNS(eif_new_type(3957, 0x00).id, 3957, _OBJSIZ_0_0_0_0_0_0_0_1_);
	*(EIF_REAL_64 *)tr1 = (EIF_REAL_64) ((EIF_REAL_64) (ti4_1) /  (EIF_REAL_64) (ti4_2));
	loc5 = F3956_47991(RTCW(tr1));
	RTHOOK(7);
	if ((EIF_BOOLEAN)(loc5 == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(8);
		loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_3_);
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 2L)) + (EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)));
		RTHOOK(9);
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	} else {
		RTHOOK(10);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_3_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
		tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) (ti4_1 - ti4_2)));
		tr8_2 = (EIF_REAL_64) (((EIF_INTEGER_32) (loc5 - ((EIF_INTEGER_32) 1L))));
		tr8_3 = *(EIF_REAL_64 *)(Current+ _R64OFF_1_0_0_5_0_0_0_0_);
		loc2 = (EIF_INTEGER_32) ((EIF_REAL_64) ((EIF_REAL_64) (tr8_1) /  (EIF_REAL_64) ((EIF_REAL_64) (tr8_2 * (EIF_REAL_64) pow ((EIF_REAL_64) (arg2), (EIF_REAL_64) (tr8_3))))));
		RTHOOK(11);
		loc2 /= arg2;
		RTHOOK(12);
		loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	}
	RTHOOK(13);
	loc6 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTHOOK(14);
	loc9 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(15);
	loc8 = F2640_30089(RTCW(arg1));
	for (;;) {
		RTHOOK(16);
		if ((EIF_BOOLEAN) (loc6 >= loc5)) break;
		RTHOOK(17);
		loc7 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		for (;;) {
			RTHOOK(18);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc7 >= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_4_)) || (EIF_BOOLEAN) (loc9 > loc8))) break;
			RTHOOK(19);
			loc10 = F2640_30074(RTCW(arg1), loc9);
			RTHOOK(20);
			if ((EIF_BOOLEAN)(arg2 == ((EIF_INTEGER_32) 1L))) {
				RTHOOK(21);
				F5743_77552(RTCW(loc10), (EIF_INTEGER_32) (loc3 + (EIF_INTEGER_32) (loc7 * loc1)), (EIF_INTEGER_32) (loc4 + (EIF_INTEGER_32) (loc6 * loc2)));
			} else {
				RTHOOK(22);
				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11283[Dtype(RTCW(loc10))-682])(loc10);
				ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11284[Dtype(RTCW(loc10))-682])(loc10);
				F5743_77552(RTCW(loc10), (EIF_INTEGER_32) (ti4_1 + (EIF_INTEGER_32) (loc7 * loc1)), (EIF_INTEGER_32) (ti4_2 + (EIF_INTEGER_32) (loc6 * loc2)));
			}
			RTHOOK(23);
			loc9++;
			RTHOOK(24);
			loc7++;
		}
		RTHOOK(25);
		loc6++;
	}
	RTHOOK(26);
	RTLE;
	RTEE;
}

void EIF_Minit1242 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
